"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class PushChangeType(str, Enum):
    UNKNOWN = 'Unknown'
    CREATED = 'Created'
    MODIFIED = 'Modified'
    DELETED = 'Deleted'
    ATTACHMENT_UPLOADED = 'AttachmentUploaded'
